@@ -186,7 +186,8 @@ def kasabi_store(dataset, filename):
     print "%s is not a valid filename" % filename
     return
 
-  if getsize(filename) < 2000000:
+  file_size = getsize(filename)
+  if file_size < 2000000:
     response, data = dataset.store_file(filename)
     if not response.status in range(200, 300):
       print "Request failed: %d %s - %s" % (response.status, response.reason, data)
@@ -202,7 +203,7 @@ def kasabi_store(dataset, filename):
     for line in f:
       data += line
       if len(data) >= 2000000:
-        print "Storing chunk %s of %s (%s bytes)" % (chunk, filename, len(data))
+        print "Storing chunk %s/%s of %s (%s bytes)" % (chunk, str(int(file_size/2000000) + 1), filename, len(data))
         response, data = dataset.store_data(data, None, content_type)
         if not response.status in range(200, 300):
           print "Request failed: %d %s - %s" % (response.status, response.reason, data)
